@@ -221,7 +221,7 @@ SimSSMIVary <- function(n, time, delta_t = 1.0,
     data <- .SimSSMIVary0(
       n = n,
       time = time,
-      delta_t = 1.0,
+      delta_t = delta_t,
       mu0 = rep(x = mu0, length.out = n),
       sigma0_l = rep(x = sigma0_l, length.out = n),
       alpha = rep(x = alpha, length.out = n),
@@ -240,7 +240,7 @@ SimSSMIVary <- function(n, time, delta_t = 1.0,
     data <- .SimSSMIVary1(
       n = n,
       time = time,
-      delta_t = 1.0,
+      delta_t = delta_t,
       mu0 = rep(x = mu0, length.out = n),
       sigma0_l = rep(x = sigma0_l, length.out = n),
       alpha = rep(x = alpha, length.out = n),
@@ -262,7 +262,7 @@ SimSSMIVary <- function(n, time, delta_t = 1.0,
     data <- .SimSSMIVary2(
       n = n,
       time = time,
-      delta_t = 1.0,
+      delta_t = delta_t,
       mu0 = rep(x = mu0, length.out = n),
       sigma0_l = rep(x = sigma0_l, length.out = n),
       alpha = rep(x = alpha, length.out = n),
